@@ -1,13 +1,15 @@
 from .KNN_Detector import KNNDetector
 from .xStream_Detector import xStreamDetector
 from .spot_Detector import SpotDetector
-from .lstm_Detector import LSTMDetector
 from .random_detector import RandomDetector
+from .rrcf_Detector import RCForest
+from .Spectral_Residual import SpectralResidual
 
 __all__ = [
     "KNNDetector",
     "xStreamDetector",
     "SpotDetector",
-    "LSTMDetector",
     "RandomDetector",
+    "RCForest",
+    "SpectralResidual",
 ]
